@@ -27,12 +27,6 @@ wkt_ranges <- function(wkt, na.rm = FALSE, finite = FALSE) {
   new_data_frame(cpp_ranges_wkt(wkt, naRm = na.rm, onlyFinite = finite))
 }
 
-#' @rdname wkb_ranges
-#' @export
-wksxp_ranges <- function(wksxp, na.rm = FALSE, finite = FALSE) {
-  new_data_frame(cpp_ranges_wksxp(wksxp, naRm = na.rm, onlyFinite = finite))
-}
-
 #' @rdname wkb_ranges
 #' @export
 wkb_feature_ranges <- function(wkb, na.rm = FALSE, finite = FALSE) {
@@ -44,9 +38,3 @@ wkb_feature_ranges <- function(wkb, na.rm = FALSE, finite = FALSE) {
 wkt_feature_ranges <- function(wkt, na.rm = FALSE, finite = FALSE) {
   new_data_frame(cpp_feature_ranges_wkt(wkt, naRm = na.rm, onlyFinite = finite))
 }
-
-#' @rdname wkb_ranges
-#' @export
-wksxp_feature_ranges <- function(wksxp, na.rm = FALSE, finite = FALSE) {
-  new_data_frame(cpp_feature_ranges_wksxp(wksxp, naRm = na.rm, onlyFinite = finite))
-}
